import { h } from "@stencil/core";
import HubApi from '@nimiq/hub-api';
const HubUrl = {
    main: 'https://hub.nimiq.com',
    test: 'https://hub.nimiq-testnet.com',
};
export class Checkout {
    constructor() {
        this.inProgress = false;
        /**
         * The theme of the button. Use light when using against dark background.
         */
        this.theme = 'dark';
        /**
         * The network you want to use. Can be 'main' or 'test'.
         */
        this.network = 'main';
    }
    async checkout() {
        this.inProgress = true;
        let options = {
            appName: this.app,
            recipient: this.recipient,
            value: this.value,
        };
        if (this.logoUrl) {
            options.shopLogoUrl = this.logoUrl;
        }
        if (this.fee) {
            options.fee = this.fee;
        }
        if (this.data) {
            options.extraData = this.data;
        }
        const hubApi = new HubApi(HubUrl[this.network]);
        try {
            const transaction = await hubApi.checkout(options);
            this.nimCheckoutSuccess.emit(transaction);
            this.inProgress = false;
        }
        catch (error) {
            this.nimCheckoutError.emit(error);
            this.inProgress = false;
        }
    }
    renderLogo(color = true) {
        if (color) {
            return (h("svg", { class: "nim-logo", "data-name": "Layer 1", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 16 16" },
                h("defs", null,
                    h("radialGradient", { id: "a", cx: "12.02", cy: "14.85", r: "15.87", gradientUnits: "userSpaceOnUse" },
                        h("stop", { offset: "0", "stop-color": "#ec991c" }),
                        h("stop", { offset: "1", "stop-color": "#e9b213" }))),
                h("path", { d: "M15.82 7.34l-3.33-5.68A1.34 1.34 0 0 0 11.33 1H4.67a1.34 1.34 0 0 0-1.16.66L.18 7.34a1.3 1.3 0 0 0 0 1.32l3.33 5.68a1.34 1.34 0 0 0 1.16.66h6.66a1.34 1.34 0 0 0 1.16-.66l3.33-5.68a1.3 1.3 0 0 0 0-1.32z", fill: "url(#a)" })));
        }
        else {
            return (h("svg", { class: "nim-logo", "data-name": "Layer 1", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 16 16" },
                h("path", { d: "M15.82 7.34l-3.33-5.68A1.34 1.34 0 0 0 11.33 1H4.67a1.34 1.34 0 0 0-1.16.66L.18 7.34a1.3 1.3 0 0 0 0 1.32l3.33 5.68a1.34 1.34 0 0 0 1.16.66h6.66a1.34 1.34 0 0 0 1.16-.66l3.33-5.68a1.3 1.3 0 0 0 0-1.32z", fill: "#fff" })));
        }
    }
    render() {
        return (h("button", { class: 'nim-theme-' + this.theme, type: "button", onClick: _ => this.checkout() },
            this.renderLogo(true),
            h("div", null, this.inProgress ? (h("span", null, "In progress...")) : (h("span", null,
                h("strong", null, "Nimiq"),
                " Checkout")))));
    }
    static get is() { return "nim-checkout"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["checkout.css"]
    }; }
    static get styleUrls() { return {
        "$": ["checkout.css"]
    }; }
    static get properties() { return {
        "theme": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "'dark' | 'light'",
                "resolved": "\"dark\" | \"light\"",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The theme of the button. Use light when using against dark background."
            },
            "attribute": "theme",
            "reflect": false,
            "defaultValue": "'dark'"
        },
        "network": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "'main' | 'test'",
                "resolved": "\"main\" | \"test\"",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The network you want to use. Can be 'main' or 'test'."
            },
            "attribute": "network",
            "reflect": false,
            "defaultValue": "'main'"
        },
        "app": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The name of your app, should be as short as possible."
            },
            "attribute": "app",
            "reflect": false
        },
        "recipient": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The human-readable address of the recipient (your shop/app)."
            },
            "attribute": "recipient",
            "reflect": false
        },
        "value": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Value of the transaction, in Luna. 1 NIM = 100000 Luna."
            },
            "attribute": "value",
            "reflect": false
        },
        "logoUrl": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "An image URL. Must be on the same origin as the request is sent from. Should be square and at least 146x146 px."
            },
            "attribute": "logo-url",
            "reflect": false
        },
        "fee": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Transaction fee in luna. Default: 0"
            },
            "attribute": "fee",
            "reflect": false
        },
        "data": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Extra data that should be sent with the transaction."
            },
            "attribute": "data",
            "reflect": false
        }
    }; }
    static get states() { return {
        "inProgress": {}
    }; }
    static get events() { return [{
            "method": "nimCheckoutSuccess",
            "name": "nimCheckoutSuccess",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "Emitted when checkout is successful"
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }, {
            "method": "nimCheckoutError",
            "name": "nimCheckoutError",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "Emitted when an error happened during checkout or it is canceled"
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }]; }
}
